@@ -417,17 +417,16 @@ class Dcim(object):
         """Return interfaces"""
         return self.netbox_con.get('/dcim/interfaces', **kwargs)
 
-    def create_interface(self, name, form_factor, device_id, **kwargs):
+    def create_interface(self, name, interface_type, device_id, **kwargs):
         """Create a new interface
 
         :param name: name of the interface
-        :param form_factor: interface type. It is not possible to get the list of form factors from the api. Search
-        in the netbox code for the correct form factor number.
+        :param interface_type: interface type. It is not possible to get the list of types from the api. Search in the netbox code for the correct type number.
         :param kwargs: optional arguments
         :param device_id: ID of the device to associate interface with
         :return: netbox object if successful otherwise raise CreateException
         """
-        required_fields = {"name": name, "form_factor": form_factor, "device": device_id}
+        required_fields = {"name": name, "type": interface_type, "device": device_id}
         return self.netbox_con.post('/dcim/interfaces/', required_fields, **kwargs)
 
     def update_interface(self, interface, device, **kwargs):
@@ -563,7 +562,6 @@ class Dcim(object):
         :param device_name: Name of device
         :param kwargs: Extra inventory items to update
         :return bool True if successful otherwise raise UpdateException
-
         """
         try:
             inventory_item_id = self.get_inventory_items(name=name, device=device_name)[0]['id']
